#
# spec file for package netdiscover
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netdiscover
Version:        0.10
Release:        1.11
Summary:        A network address discovering/monitoring tool
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/netdiscover-scanner/netdiscover
Source0:        https://github.com/netdiscover-scanner/netdiscover/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dos2unix
BuildRequires:  hwdata
BuildRequires:  libnet-devel >= 1.1.2
BuildRequires:  libpcap-devel

%description
Netdiscover is an active/passive address reconnaissance tool, mainly developed
for those wireless networks without dhcp server, when you are wardriving. It
can be also used on hub/switched networks.

Built on top of libnet and libpcap, it can passively detect online hosts, or
search for them, by actively sending arp requests, it can also be used to
inspect your network arp traffic, and find network addresses using auto scan
mode, which will scan for common local networks.

%prep
%autosetup

%build
autoreconf -fiv
%configure
cp -p %{_datadir}/hwdata/oui.txt ./oui.txt-$(date +%Y%m%d)
sh update-oui-database.sh --no-download
%make_build

%install
%make_install
rm -rf %{buildroot}%{_datadir}/doc

%files
%license COPYING
%doc ChangeLog README AUTHORS NEWS TODO
%{_sbindir}/netdiscover
%{_mandir}/man8/netdiscover.8%{?ext_man}

%changelog
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.10:
  * Changed secure download site from https://linuxnet.ca/ieee/oui.txt (link
    down) to https://standards-oui.ieee.org in update-oui-database.sh
  * script.
  * Fixed segfault when HOME env is not set. Thanks to Till Zimmermann
    tzimmermann@uos.de.
  * Use unsigned int for data_counter.hosts. Thanks to Brendan Coles
    bcoles@gmail.com
  * Updated OUI table.
* Wed Mar 16 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.9:
  * ifaces: process_packet: Return if source MAC address matches
    host MAC.
* Fri Nov  5 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.1
  * Replaced deprecated function pcap_lookupdev
  * Updated OUI table
* Thu Oct 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.8:
  * Changed PCAP_TOUT from 0 to 512 in src/ifaces.h, to avoid no
    results whe scanning with CIDR /24 if netdiscover is being
    built with libpcap >= 1.10.
* Thu Dec 17 2020 Martin Pluskal <mpluskal@suse.com>
- Update minimal requirement for libnet
- Fix usage of hwdata oui
* Thu Aug 13 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.7:
  * Updated create-man.sh to 2.0 version.
  * Updated manpage dates.
  * Updated update-oui-database.sh to be useful in macOS.
  * Updated OUI table.
* Tue May 12 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.6:
  * Fix build with GCC 10. (Jaime Peñalba)
* Fri Feb 28 2020 Martin Pluskal <mpluskal@suse.com>
- Update project url
- Drop no longer needed patches:
  * netdiscover-fix-spelling-binary.patch
  * netdiscover-fix-manpage.patch
  * netdiscover-fix-makefile.patch
  * netdiscover-update-oui.patch
- Update to version 0.5.1:
  * Added an official repository notice in README.
  * Added dates of releases in ChangeLog.
  * Added some copyright notices.
  * Several important fixes and improvements in manpage and help page.
- For changes for previous releses see provided Changelog
* Wed Feb 28 2018 mpluskal@suse.com
- Run spec-cleaner:
  * Use spdx-3.0
  * Mark license as such
* Mon Jul 24 2017 mpluskal@suse.com
- Cleaned up spec file with spec-cleaner
- Add patches:
  * netdiscover-update-oui.patch
  * netdiscover-fix-makefile.patch
  * netdiscover-fix-spelling-binary.patch
  * netdiscover-fix-manpage.patch
* Sun May 22 2016 AxelKoellhofer@web.de - 0.3_beta7
- updated sources from svn
  * fix for debian bug #818791
  * updated oui update script
- updated oui database
* Sun Jun 21 2015 AxelKoellhofer@web.de - 0.3_beta7
- updated oui database
* Wed May 20 2015 AxelKoellhofer@web.de - 0.3_beta7
- updated oui database
* Sat May  2 2015 AxelKoellhofer@web.de - 0.3_beta7
- updated to 0.3 beta7 pre-release
- updated oui database
  Sun Mar 24 00:00:00 UTC 2013 - blingblong
- Initial openSUSE .spec
- Patch updates oui.h with updated MAC addresses
* Tue May  2 2006 jpenalbae@gmail.com
- Modified for RedHat/Fedora
* Wed Apr 26 2006 francis.giraldeau@revolutionlinux.com
- Correction of installation directories
* Mon Mar 27 2006 francis.giraldeau@revolutionlinux.com
- Initial writing
